@@ -166,7 +166,7 @@ import numpy as _np
 import copy as _copy
 
 @dataclass
-class _TReactionType:
+class TReactionType:
       UNIUNI = 0
       BIUNI = 1
       UNIBI = 2
@@ -176,12 +176,12 @@ class _TReactionType:
 def _pickReactionType():
        rt = _random.random()
        if rt < Settings.ReactionProbabilities.UniUni:
-           return _TReactionType.UNIUNI
+           return TReactionType.UNIUNI
        if rt < Settings.ReactionProbabilities.UniUni + Settings.ReactionProbabilities.BiUni:
-           return _TReactionType.BIUNI
+           return TReactionType.BIUNI
        if rt < Settings.ReactionProbabilities.UniUni + Settings.ReactionProbabilities.BiUni + Settings.ReactionProbabilities.UniBi:
-           return _TReactionType.UNIBI
-       return _TReactionType.BIBI
+           return TReactionType.UNIBI
+       return TReactionType.BIBI
     
     
 # Generates a reaction network in the form of a reaction list
@@ -198,7 +198,7 @@ def _generateReactionList (nSpecies, nReactions):
         
        rateConstant = _random.random()*Settings.rateConstantScale
        rt = _pickReactionType()
-       if rt == _TReactionType.UNIUNI:
+       if rt == TReactionType.UNIUNI:
            # UniUni
            reactant = _random.randint (0, nSpecies-1)
            product = _random.randint (0, nSpecies-1)
@@ -207,7 +207,7 @@ def _generateReactionList (nSpecies, nReactions):
                  product = _random.randint (0, nSpecies-1)
            reactionList.append ([rt, [reactant], [product], rateConstant]) 
                
-       if rt == _TReactionType.BIUNI:
+       if rt == TReactionType.BIUNI:
            # BiUni
            # Pick two reactants
            reactant1 = _random.randint (0, nSpecies-1)
@@ -224,7 +224,7 @@ def _generateReactionList (nSpecies, nReactions):
                
            reactionList.append ([rt, [reactant1, reactant2], [product], rateConstant]) 
 
-       if rt == _TReactionType.UNIBI:
+       if rt == TReactionType.UNIBI:
           # UniBi
           reactant1 = _random.randint (0, nSpecies-1)
           if Settings.allowMassViolatingReactions:
@@ -241,7 +241,7 @@ def _generateReactionList (nSpecies, nReactions):
     
           reactionList.append ([rt, [reactant1], [product1, product2], rateConstant]) 
 
-       if rt == _TReactionType.BIBI:
+       if rt == TReactionType.BIBI:
           # BiBi
           reactant1 = _random.randint (0, nSpecies-1)
           reactant2= _random.randint (0, nSpecies-1)
@@ -260,7 +260,7 @@ def _generateReactionList (nSpecies, nReactions):
           element = [rt, [reactant1, reactant2], [product1, product2], rateConstant]
           reactionList.append (element)            
 
-    reactionList.insert (0, nSpecies)
+    reactionList.insert (0, nReactions)
     return reactionList
     
 
@@ -275,14 +275,14 @@ def _getFullStoichiometryMatrix (reactionList):
     st = _np.zeros ((nSpecies, len(reactionListCopy)))
     
     for index, r in enumerate (reactionListCopy):
-        if r[0] == _TReactionType.UNIUNI:
+        if r[0] == TReactionType.UNIUNI:
            # UniUni
            reactant = reactionListCopy[index][1][0]
            st[reactant, index] = -1
            product = reactionListCopy[index][2][0]
            st[product, index] = 1
      
-        if r[0] == _TReactionType.BIUNI:
+        if r[0] == TReactionType.BIUNI:
             # BiUni
             reactant1 = reactionListCopy[index][1][0]
             st[reactant1, index] = -1
@@ -291,7 +291,7 @@ def _getFullStoichiometryMatrix (reactionList):
             product = reactionListCopy[index][2][0]
             st[product, index] = 1
 
-        if r[0] == _TReactionType.UNIBI:
+        if r[0] == TReactionType.UNIBI:
             # UniBi
             reactant1 = reactionListCopy[index][1][0]
             st[reactant1, index] = -1
@@ -300,7 +300,7 @@ def _getFullStoichiometryMatrix (reactionList):
             product2 = reactionListCopy[index][2][1]
             st[product2, index] = 1
 
-        if r[0] == _TReactionType.BIBI:
+        if r[0] == TReactionType.BIBI:
             # BiBi
             reactant1 = reactionListCopy[index][1][0]
             st[reactant1, index] = -1
@@ -375,7 +375,7 @@ def _getAntimonyScript (floatingIds, boundaryIds, reactionList, isReversible):
     
     for reactionIndex, r in enumerate (reactionListCopy):
         antStr = antStr + 'J' + str (reactionIndex) + ': '
-        if r[0] == _TReactionType.UNIUNI:
+        if r[0] == TReactionType.UNIUNI:
            # UniUni
            antStr = antStr + 'S' + str (reactionListCopy[reactionIndex][1][0])
            antStr = antStr + ' -> '
@@ -384,7 +384,7 @@ def _getAntimonyScript (floatingIds, boundaryIds, reactionList, isReversible):
            if isReversible:
               antStr = antStr + ' - k' + str (reactionIndex) + 'r' + '*S' + str (reactionListCopy[reactionIndex][2][0])
            antStr = antStr + ')'
-        if r[0] == _TReactionType.BIUNI:
+        if r[0] == TReactionType.BIUNI:
            # BiUni
            antStr = antStr + 'S' + str (reactionListCopy[reactionIndex][1][0])
            antStr = antStr + ' + '
@@ -395,7 +395,7 @@ def _getAntimonyScript (floatingIds, boundaryIds, reactionList, isReversible):
            if isReversible:
              antStr = antStr + ' - k' + str (reactionIndex) + 'r' + '*S' + str (reactionListCopy[reactionIndex][2][0])
            antStr = antStr + ')'
-        if r[0] == _TReactionType.UNIBI:
+        if r[0] == TReactionType.UNIBI:
            # UniBi
            antStr = antStr + 'S' + str (reactionListCopy[reactionIndex][1][0])
            antStr = antStr + ' -> '
@@ -406,7 +406,7 @@ def _getAntimonyScript (floatingIds, boundaryIds, reactionList, isReversible):
            if isReversible:
              antStr = antStr + ' - k' + str (reactionIndex) + 'r' + '*S' + str (reactionListCopy[reactionIndex][2][0]) + '*S' + str (reactionListCopy[reactionIndex][2][1])
            antStr = antStr + ')'
-        if r[0] == _TReactionType.BIBI:
+        if r[0] == TReactionType.BIBI:
            # BiBi
            antStr = antStr + 'S' + str (reactionListCopy[reactionIndex][1][0])
            antStr = antStr + ' + '
@@ -477,7 +477,7 @@ def getRandomNetworkDataStructure (nSpecies, nReactions, isReversible=False, ran
 
     """   
     if not importRoadrunnerFail:
-        roadrunner.Logger_disableConsoleLogging()
+        #roadrunner.Logger_disableConsoleLogging()
         roadrunner.Config_setValue (roadrunner.Config.ROADRUNNER_DISABLE_WARNINGS, True)
 
     if randomSeed != -1:
@@ -490,7 +490,7 @@ def getRandomNetworkDataStructure (nSpecies, nReactions, isReversible=False, ran
      
     if Settings.addDegradationSteps:
        for sp in stt[1]:
-           rl.append ([_TReactionType.UNIUNI, [sp], [], 0.01])
+           rl.append ([TReactionType.UNIUNI, [sp], [], 0.01])
             
     return [stt[1], stt[2], rl, isReversible]
 
